==> exonmap_1.4.3.tar.gz: exonmap/R/pc.R <==
library("methods")
library("affy")

# holds the results of a pairwise comparison
setClass("PC",representation(fc="numeric",tt="numeric"))

#accessor methods
setGeneric("fc", function(object) standardGeneric("fc"))
setMethod("fc","PC",function(object) object@fc)

setGeneric("tt", function(object) standardGeneric("tt"))
setMethod("tt","PC",function(object) object@tt)


##subsetting. can only happen by gene

setMethod("[", "PC", function(x,i,j,...,drop=FALSE) {
  new("PC",fc=fc(x)[i,...,drop=FALSE],tt=tt(x)[i,...,drop=FALSE])
})

setReplaceMethod("[", "PC", function(x, i,j,...,value) {
  stop("operation not supported");
})



## selecting groups of arrays based on their annotation in pData

.ss.exprset <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  return(x[,is.element(grp,members)]);
}

.ss.affybatch <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  return(x[,is.element(grp,members)]);
}

group.indices <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  i <- 1:length(grp)
  return(i[is.element(grp,members)]);
}

setGeneric("array.subset", function(x,group,members) standardGeneric("array.subset"))
setMethod("array.subset","AffyBatch",.ss.affybatch);
setMethod("array.subset","exprSet",.ss.exprset);


 
pc <- function(x,group,members) {
  if(class(x) != "ExpressionSet") {stop("'x' must be an ExpressionSet object.") }  
  if(missing(group)) { stop("Must specify a group to test against.") }
  fac <- pData(x)[,group]
  if(missing(members)) {
    members <- levels(fac)
    if(length(members) != 2) { stop(paste("The specified group, '",group,"', must have exactly two members.",sep=""))} 
  }
  keep <- fac %in% members
  fac <- factor(fac[keep],levels=members)
  r <- rowttests(exprs(x)[,keep],fac)
  names(r$dm)      <- rownames(exprs(x))
  names(r$p.value) <- rownames(exprs(x))
  return(new("PC",fc=r$dm,tt=r$p.value))
}

==> exonmap_1.6.06.tar.gz: exonmap/R/pc.R <==
library("methods")
library("affy")

# holds the results of a pairwise comparison
setClass("PC",representation(fc="numeric",tt="numeric"))

#accessor methods
setGeneric("fc", function(object) standardGeneric("fc"))
setMethod("fc","PC",function(object) object@fc)

setGeneric("tt", function(object) standardGeneric("tt"))
setMethod("tt","PC",function(object) object@tt)


##subsetting. can only happen by gene

setMethod("[", "PC", function(x,i,j,...,drop=FALSE) {
  new("PC",fc=fc(x)[i,...,drop=FALSE],tt=tt(x)[i,...,drop=FALSE])
})

setReplaceMethod("[", "PC", function(x, i,j,...,value) {
  stop("operation not supported");
})



## selecting groups of arrays based on their annotation in pData

.ss.exprset <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  return(x[,is.element(grp,members)]);
}

.ss.affybatch <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  return(x[,is.element(grp,members)]);
}

group.indices <- function(x,group,members) {
  pd <- pData(x);
  grp <- pd[,colnames(pd) == group];
  i <- seq_along(grp)
  return(i[is.element(grp,members)]);
}

setGeneric("array.subset", function(x,group,members) standardGeneric("array.subset"))
setMethod("array.subset","AffyBatch",.ss.affybatch);
setMethod("array.subset","ExpressionSet",.ss.exprset);

 
pc <- function(x,group,members) {
  if(class(x) != "ExpressionSet") {stop("'x' must be an ExpressionSet object.") }  
  if(missing(group)) { stop("Must specify a group to test against.") }
  fac <- pData(x)[,group]
  if(missing(members)) {
    members <- levels(fac)
    if(length(members) != 2) { stop(paste("The specified group, '",group,"', must have exactly two members.",sep=""))} 
  }
  keep <- fac %in% members
  fac <- factor(fac[keep],levels=members)
  r <- rowttests(exprs(x)[,keep],fac)
  r.fc <- r$dm
  r.tt <- r$p.value
  names(r.fc) <- rownames(r)
  names(r.tt) <- rownames(r)
  return(new("PC",fc=r.fc,tt=r.tt))
}
